==> pyabaqus-1.0.3-py2.py3-none-any.whl: abaqus/InputFileParser/InputFile.py <==
from abaqusConstants import *


class InputFile:
    """The InputFile object is used to store the definitions in an Abaqus input file. InputFile
    objects can be created using the methods described in this section. 

    Access
    ------
        - import inpParser

    Table Data
    ----------

    Corresponding analysis keywords
    -------------------------------

    """

    # A String specifying the source file name of the Abaqus input file. 
    file: str = ''

    # A String specifying the directory where the input file is located. 
    directory: str = ''

    # A sequence of Strings specifying any additional input files included in the specified 
    # input file. 
    includes: tuple = ()

    # A sequence of Strings for input files included in the specified input file that could 
    # not be located. 
    missingIncludes: tuple = ()

    def __init__(self, file: str, directory: str = ''):
        """This method creates an InputFile object by reading an Abaqus input file.

        Path
        ----
            - inpParser.InputFile

        Parameters
        ----------
        file
            A String specifying the path to the input file. 
        directory
            A String specifying the path to the directory containing the input file. 

        Returns
        -------
            An InputFile object. 

        Exceptions
        ----------
            None. 
        """
        pass

    def parse(self, organize: Boolean = False, verbose: Boolean = False, bulk: Boolean = True,
              usePyArray: Boolean = False):
        """This method parses the input file associated with the InputFile object.

        Parameters
        ----------
        organize
            A Boolean specifying whether keywords should be organized into suboptions. The default 
            is False. 
        verbose
            A Boolean specifying whether verbose output is to be printed. If *verbose* is True, 
            information about fatal errors is printed. If no fatal errors occur, there is no output. 
            The default is False. 
        bulk
            A Boolean specifying whether the input file includes bulk data that should be parsed. 
            The default is True. 
        usePyArray
            A Boolean specifying that parse method can return an AbaqusNDarray object for a keyword 
            data value. In cases where large amounts of numerical data (i.e., large node arrays) are 
            expected, it is recommended that you use the option usePyArray=True. The default is 
            False. 

        Returns
        -------
            A KeywordSequence object. 

        Exceptions
        ----------
            If you parse an input file more than once, a ValueError is raised for each subsequent 
            parsing. 
        """
        pass

==> pyabaqus-1.0.5-py2.py3-none-any.whl: abaqus/InputFileParser/InputFile.py <==
from abaqusConstants import *


class InputFile:
    """The InputFile object is used to store the definitions in an Abaqus input file. InputFile
    objects can be created using the methods described in this section. 

    Access
    ------
        - import inpParser

    Table Data
    ----------

    Corresponding analysis keywords
    -------------------------------

    """

    # A String specifying the source file name of the Abaqus input file. 
    file: str = ''

    # A String specifying the directory where the input file is located. 
    directory: str = ''

    # A sequence of Strings specifying any additional input files included in the specified 
    # input file. 
    includes: tuple = ()

    # A sequence of Strings for input files included in the specified input file that could 
    # not be located. 
    missingIncludes: tuple = ()

    def __init__(self, file: str, directory: str = ''):
        """This method creates an InputFile object by reading an Abaqus input file.

        Path
        ----
            - inpParser.InputFile

        Parameters
        ----------
        file
            A String specifying the path to the input file. 
        directory
            A String specifying the path to the directory containing the input file. 

        Returns
        -------
            An InputFile object. . 
        """
        pass

    def parse(self, organize: Boolean = False, verbose: Boolean = False, bulk: Boolean = True,
              usePyArray: Boolean = False):
        """This method parses the input file associated with the InputFile object.

        Parameters
        ----------
        organize
            A Boolean specifying whether keywords should be organized into suboptions. The default 
            is False. 
        verbose
            A Boolean specifying whether verbose output is to be printed. If *verbose* is True, 
            information about fatal errors is printed. If no fatal errors occur, there is no output. 
            The default is False. 
        bulk
            A Boolean specifying whether the input file includes bulk data that should be parsed. 
            The default is True. 
        usePyArray
            A Boolean specifying that parse method can return an AbaqusNDarray object for a keyword 
            data value. In cases where large amounts of numerical data (i.e., large node arrays) are 
            expected, it is recommended that you use the option usePyArray=True. The default is 
            False. 

        Returns
        -------
            A KeywordSequence object. 

        Exceptions
        ----------
            If you parse an input file more than once, a ValueError is raised for each subsequent 
            parsing. 
        """
        pass
